import { vitePreprocess } from '@sveltejs/vite-plugin-svelte';
import { mdsvex } from 'mdsvex';
import adapter from '@sveltejs/adapter-static';

import remarkAlert from './src/lib/markdown.js'
import relativeImages from 'mdsvex-relative-images'
import remarkToc from 'remark-toc'
import rehypeSlug from 'rehype-slug'

const contentDir = process.env?.CHRYSOBLOG_CONTENT ?? "src/content";

/** @type {import('@sveltejs/kit').Config} */
const config = {
	// Consult https://kit.svelte.dev/docs/integrations#preprocessors
	// for more information about preprocessors
	preprocess: [
      mdsvex({
         extensions: ['.md'],
         remarkPlugins: [
            remarkAlert,
            relativeImages,
            [remarkToc, {tight: true}],
         ],
         rehypePlugins: [
            rehypeSlug,
         ]
      }),
      vitePreprocess(),
   ],
   extensions: [".svelte", ".md"],

	kit: {
		// adapter-auto only supports some environments, see https://kit.svelte.dev/docs/adapter-auto for a list.
		// If your environment is not supported, or you settled on a specific environment, switch out the adapter.
		// See https://kit.svelte.dev/docs/adapters for more information about adapters.
		adapter: adapter({
         pages: "build",
         assets: "build",
         fallback: null,
         precompress: false,
         trailingSlash: 'always',
      }),
      prerender: {
         crawl: true,
         entries: [
            "/page/1/",
         ],
      },
		alias: {
         $content: contentDir,
			"@/*": "./*",
		},
	}
};

export default config;
